.. Copyright (C) 2016-2017 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2016-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _Firejail 0.9.38 Release Announcement: https://l3net.wordpress.com/2016/02/04/firejail-0-9-38-release-announcement/
.. _ypid_firejail-scripts: https://github.com/ypid/firejail-scripts
